@@ -46,12 +46,9 @@ Bio::Tools::Run::Alignment::Lagan - Object for the local execution of the LAGAN
 
 =head1 DESCRIPTION
 
-To run mlagan/lagan, you must have an environment variable that points to
-the executable directory with files lagan.pl etc.
-"LAGAN_DIR=/opt/lagan_executables/"
-
-Simply having the executables in your path is not supported because the
-executables themselves only work with the environment variable set.
+To run mlagan/lagan, the executables "mlagan" and "lagan.pl" must be
+in your path or you must have an environment variable that points to
+the executable directory "LAGANDIR=/opt/lagan_executables/"
 
 All lagan and mlagan parameters listed in their Readmes can be set
 except for the mfa flag which has been turned on by default to prevent
@@ -91,16 +88,17 @@ Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via the
-web:
+of the bugs and their resolution. Bug reports can be submitted via
+email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Stephen Montgomery
 
@@ -133,7 +131,6 @@ use Bio::AlignIO;
 use Bio::AlignIO::fasta;
 use Bio::SimpleAlign;
 use Bio::Tools::Run::WrapperBase;
-use Cwd;
 
 @ISA = qw(	Bio::Root::Root
 		Bio::Tools::Run::WrapperBase);
@@ -155,8 +152,9 @@ BEGIN {
         $OK_FIELD{$attr}++;
     }
 
-    #The LAGAN_DIR environment variable must be set
-    $PROGRAM_DIR = $ENV{'LAGAN_DIR'} || '';
+    #The LAGANDIR environment variable should be set if the lagan
+    #executables aren't in your path.
+    $PROGRAM_DIR = $ENV{'LAGANDIR'} || '';
 }
 
 sub new {
@@ -377,9 +375,10 @@ sub _runlagan {
     my ($self, $executable, $param_string, $input1, $input2) = @_;
     my ($lagan_obj, $exe);
     if ( ! ($exe = $self->executable($executable))) {
-        return;
+        $self->warn("cannot find path to $executable");
+        return undef;
     }
-    
+
     my $command_string;
     if ($executable eq 'lagan.pl') {
         $command_string = $exe . " " . $input1 . " " . $input2 . $param_string;
@@ -397,32 +396,12 @@ sub _runlagan {
 
     if (($self->silent ||  $self->quiet) &&
         ($^O !~ /os2|dos|MSWin32|amigaos/)) {
-      $command_string .= ' > /dev/null 2> /dev/null';
+      $command_string .= ' 2> /dev/null';
 
     }
     
-    # will do brute-force clean up of junk files generated by lagan
-    my $cwd = cwd();
-    opendir(my $cwd_dir, $cwd) || $self->throw("Could not open the current directory '$cwd'!");
-    my %ok_files;
-    foreach my $thing (readdir($cwd_dir)) {
-        if ($thing =~ /anch/) {
-            $ok_files{$thing} = 1;
-        }
-    }
-    closedir($cwd_dir);
-    
     $self->debug("$command_string\n");
-    my $status = system('_POSIX2_VERSION=1 '.$command_string); # temporary hack whilst lagan script 'rechaos.pl' uses obsolete sort syntax
-    
-    opendir($cwd_dir, $cwd) || $self->throw("Could not open the current directory '$cwd'!");
-    foreach my $thing (readdir($cwd_dir)) {
-        if ($thing =~ /anch/) {
-            unlink($thing) unless $ok_files{$thing};
-        }
-    }
-    closedir($cwd_dir);
-    
+    my $status = system($command_string);
     my $outfile = $self->out();
     my $align = Bio::AlignIO->new(	'-file' => $outfile,
 					'-format' => 'fasta' );
@@ -455,8 +434,8 @@ sub executable {
     unless ( defined $self->{'_pathtoexe'}->{$exename} ) {
         my $f = $self->program_path($exename);
         $exe = $self->{'_pathtoexe'}->{$exename} = $f if(-e $f && -x $f );
-        
-        unless( $exe )  {
+
+        unless( $exe )  { 
             if ( ($exe = $self->io->exists_exe($exename)) && -x $exe ) {
                 $self->{'_pathtoexe'}->{$exename} = $exe;
             } else {
@@ -465,14 +444,6 @@ sub executable {
             }
         }
     }
-    
-    # even if its executable, we still need the environment variable to have
-    # been set
-    if (! $PROGRAM_DIR) {
-        $self->warn("Environment variable LAGAN_DIR must be set, even if the lagan executables are in your path");
-        $self->{'_pathtoexe'}->{$exename} = undef;
-    }
-    
     return $self->{'_pathtoexe'}->{$exename};
 }
 
