@@ -1,8 +1,8 @@
-# $Id: Analysis.pm,v 1.11 2006/07/04 22:23:31 mauricio Exp $
+# $Id: Analysis.pm,v 1.6 2003/06/04 08:48:26 heikki Exp $
 #
 # BioPerl module for Bio::Tools::Run::Analysis
 #
-# Cared for by Martin Senger <martin.senger@gmail.com>
+# Cared for by Martin Senger <senger@ebi.ac.uk>
 # For copyright and disclaimer see below.
 #
 
@@ -111,25 +111,30 @@ tools in a unified way that allows adding new access methods
 (protocols) seamlessly.
 
 At the moment of writing, there is available a I<SOAP> access to
-almost all EMBOSS applications, running at the
-European Bioinformatics Institute.
+almost all EMBOSS applications (running as an experimental service at
+European Bioinformatics Institute. The I<CORBA> access will follow
+shortly (it is already implemented in the C<novella> project -
+http://industry.ebi.ac.uk/novella , and it requires now to write only a
+small bridge to the C<Bio::Tools::Run::Analysis> module). A challenging but
+important task will be to make available also local analysis (some of
+them already being a part of bioperl).
 
 The documentation of all C<public> methods are to be found
 in C<Bio::AnalysisI>. A tutorial (and examples how to call almost all
-public methods) is in the script C<panalysis.PLS> (go to the C<scripts>
-directory and type C<perldoc panalysis.PLS>).
+public methods) is in the script C<analysis.pl> (go to the C<scripts>
+directory and type C<perldoc analysis.pl>).
 
 The module C<Bio::Tools::Run::Analysis> uses general approach allowing to set
 arbitrary input data and to retrieve results by naming them. However,
 sometimes is more convenient to use a specific module, representing
 one analysis tool, that already knows about available input and result
 names. Such analyses-specific Perl modules can be generated by
-C<papplmaker.PLS> generator. Its features and usage are documented in
+C<applmaker.pl> generator. Its features and usage are documented in
 the generator (go to the C<scripts> directory and type C<perldoc
-papplmaker.PLS>).
+applmaker.pl>).
 
   # this will generate module Seqret.pm
-  perl papplmaker.PLS -n edit.seqret -m Seqret
+  applmaker.pl -n edit::seqret -m Seqret
 
   # ...which can be used with data-specific methods
   use Seqret;
@@ -149,20 +154,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via the
-web:
+of the bugs and their resolution. Bug reports can be submitted via
+email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bioperl.org/bioperl-bugs/
 
 =head1 AUTHOR
 
-Martin Senger (martin.senger@gmail.com)
+Martin Senger (senger@ebi.ac.uk)
 
 =head1 COPYRIGHT
 
@@ -182,7 +188,7 @@ This software is provided "as is" without warranty of any kind.
 
 =item *
 
-http://www.ebi.ac.uk/soaplab/Perl_Client.html
+http://industry.ebi.ac.uk/soaplab/Perl_Client.html
 
 =back
 
@@ -205,7 +211,7 @@ use Bio::AnalysisI;
 @ISA = qw(Bio::Root::Root Bio::AnalysisI);
 
 BEGIN {
-    $Revision = q[$Id: Analysis.pm,v 1.11 2006/07/04 22:23:31 mauricio Exp $];
+    $Revision = q$Id: Analysis.pm,v 1.6 2003/06/04 08:48:26 heikki Exp $;
 }
 
 # -----------------------------------------------------------------------------
@@ -214,7 +220,7 @@ BEGIN {
 
  Usage   : my $tool =
              new Bio::Tools::Run::Analysis (-access => 'soap',
-                                            -name => 'edit.seqret',
+                                            -name => 'edit::seqret',
                                             ...
                                             );
  Returns : a new Bio::Tools::Run::Analysis object representing the given tool
@@ -241,7 +247,7 @@ parameter.
 =item -access
 
 It indicates what lower-level module to load.  Default is 'soap'.
-Other (but future) possibilities may be:
+Other (but future) possibilities are:
 
    -access => 'novella'
    -access => 'local'
@@ -251,9 +257,9 @@ Other (but future) possibilities may be:
 A location of the service. The contents is access-specific (see
 details in the lower-level implementation modules).
 
-Default is C<http://www.ebi.ac.uk/soaplab/services> ( services running
-at European Bioinformatics Institute on top of most of EMBOSS
-analyses, and on few others).
+Default is C<http://industry.ebi.ac.uk/soap/soaplab> (an experimental
+service running at European Bioinformatics Institute on top of most of
+EMBOSS analyses; it is a Web Service using SOAP access).
 
 =item -name
 
@@ -540,7 +546,7 @@ use Bio::Root::Root;
 
  Usage   : my $job = new Bio::Tools::Run::Analysis::Job
                        (-access => 'soap',
-                        -name => 'edit.seqret',
+                        -name => 'edit::seqret',
                         -id => 'xxxyyy111222333'
                         );
  Returns : a re-created object representing a job
