@@ -1,8 +1,8 @@
-# $Id: AnalysisFactory.pm,v 1.10 2006/07/04 22:23:31 mauricio Exp $
+# $Id: AnalysisFactory.pm,v 1.6 2003/06/04 08:48:26 heikki Exp $
 #
 # BioPerl module for Bio::Tools::Run::AnalysisFactory
 #
-# Cared for by Martin Senger <martin.senger@gmail.com>
+# Cared for by Martin Senger <senger@ebi.ac.uk>
 # For copyright and disclaimer see below.
 #
 
@@ -55,7 +55,7 @@ Bio::Tools::Run::AnalysisFactory - A directory of analysis tools
   # create an analysis object
   use Bio::Tools::Run::AnalysisFactory;
   $service = new Bio::Tools::Run::AnalysisFactory
-                 ->create_analysis ('edit.seqret');
+                 ->create_analysis ('edit::seqret');
   $service->run (
                 #...
                 )->results;
@@ -71,8 +71,14 @@ The module is a higher-level abstraction whose main job is to load a
 C<-access> parameter. The same design is used here as for
 C<Bio::Tools::Run::Analysis> module.
 
-There is available a I<SOAP> access to almost all EMBOSS applications,
-running at European Bioinformatics Institute.
+At the moment of writing, there is available a I<SOAP> access to
+almost all EMBOSS applications (running as an experimental service at
+European Bioinformatics Institute. The I<CORBA> access will follow
+shortly (it is already implemented in the C<novella> project -
+http://industry.ebi.ac.uk/novella , and it requires now to write only a
+small bridge to the C<Bio::Tools::Run::Analysis> module). A challenging but
+important task will be to make available also local analysis (some of
+them already being a part of bioperl).
 
 The documentation of all C<public> methods are to be found
 in C<Bio::Factory::AnalysisI>.
@@ -85,20 +91,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via the
-web:
+of the bugs and their resolution. Bug reports can be submitted via
+email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bioperl.org/bioperl-bugs/
 
 =head1 AUTHOR
 
-Martin Senger (martin.senger@gmail.com)
+Martin Senger (senger@ebi.ac.uk)
 
 =head1 COPYRIGHT
 
@@ -118,7 +125,7 @@ This software is provided "as is" without warranty of any kind.
 
 =item *
 
-http://www.ebi.ac.uk/soaplab/Perl_Client.html
+http://industry.ebi.ac.uk/soaplab/Perl_Client.html
 
 =back
 
@@ -142,7 +149,7 @@ use Bio::Factory::AnalysisI;
 
 
 BEGIN {
-    $Revision = q$Id: AnalysisFactory.pm,v 1.10 2006/07/04 22:23:31 mauricio Exp $;
+    $Revision = q$Id: AnalysisFactory.pm,v 1.6 2003/06/04 08:48:26 heikki Exp $;
 }
 
 # -----------------------------------------------------------------------------
@@ -192,9 +199,9 @@ Other (but future) possibilities are:
 A location of the service. The contents is access-specific (see
 details in the lower-level implementation modules).
 
-Default is C<http://www.ebi.ac.uk/soaplab/services> (there are
-services running at European Bioinformatics Institute on top of most
-of EMBOSS analyses, and on some others).
+Default is C<http://industry.ebi.ac.uk/soap/soaplab> (an experimental
+service running at European Bioinformatics Institute on top of most of
+EMBOSS analyses; it is a Web Service using SOAP access).
 
 =item -httpproxy
 
