@@ -1,7 +1,10 @@
-# $Id: EMBOSSApplication.pm,v 1.28 2006/10/21 20:51:59 bosborne Exp $
+ # $Id: EMBOSSApplication.pm,v 1.17 2003/08/14 21:16:04 jason Exp $
 #
 # BioPerl module for Bio::Tools::Run::EMBOSSApplication
 #
+#
+# Cared for by Heikki Lehvaslaiho <heikki@ebi.ac.uk>
+#
 # Copyright Heikki Lehvaslaiho
 #
 # You may distribute this module under the same terms as perl itself
@@ -10,7 +13,7 @@
 
 =head1 NAME
 
-Bio::Tools::Run::EMBOSSApplication - class for EMBOSS Applications
+Bio::Tools::Run::EMBOSSApplication -  class for EMBOSS Applications
 
 =head1 SYNOPSIS
 
@@ -27,28 +30,28 @@ Bio::Tools::Run::EMBOSSApplication - class for EMBOSS Applications
   # here is an example of running the application
   # water can compare 1 seq against 1->many sequences
   # in a database using Smith-Waterman
-  my $seq_to_test;     # this would have a seq here
+  my $seq_to_test; # this would have a seq here
   my @seqs_to_check; # this would be a list of seqs to compare 
-
+                     # (could be just 1)
   my $wateroutfile = 'out.water';
-  $water->run({-sequencea => $seq_to_test,
-               -seqall    => \@seqs_to_check,
-               -gapopen   => '10.0',
-               -gapextend => '0.5',
-               -outfile   => $wateroutfile});
+  $water->run({ '-sequencea' => $seq_to_test,
+              '-seqall'    => \@seqs_to_check,
+              '-gapopen'   => '10.0',
+              '-gapextend' => '0.5',
+              '-outfile'   => $wateroutfile});
   # now you might want to get the alignment
   use Bio::AlignIO;
   my $alnin = new Bio::AlignIO(-format => 'emboss',
-			                      -file   => $wateroutfile);
+			       -file   => $wateroutfile);
 
-  while ( my $aln = $alnin->next_aln ) {
+  while( my $aln = $alnin->next_aln ) {
       # process the alignment -- these will be Bio::SimpleAlign objects
   }
 
 =head1 DESCRIPTION
 
 The EMBOSSApplication class can represent EMBOSS any program. It is
-created by a L<Bio::Factory::EMBOSS> object.
+created by a Bio::Factory::EMBOSS object.
 
 If you want to check command line options before sending them to the
 program set $prog-E<gt>verbose to positive integer. The ADC
@@ -65,24 +68,30 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to the
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org                         - General discussion
+  http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
-Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+report bugs to the Bioperl bug tracking system to help us keep track
+ the bugs and their resolution.  Bug reports can be submitted via
+ email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bio.perl.org/bioperl-bugs/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
-Email  heikki-at-bioperl-dot-org
+Email:  heikki@ebi.ac.uk
+Address:
+
+     EMBL Outstation, European Bioinformatics Institute
+     Wellcome Trust Genome Campus, Hinxton
+     Cambs. CB10 1SD, United Kingdom
 
 =head2 CONTRIBUTORS
 
-Email: jason-AT-bioperl_DOT_org
+Email: jason@bioperl.org
 
 =head1 APPENDIX
 
@@ -94,11 +103,13 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Tools::Run::EMBOSSApplication;
-use vars qw( $SEQIOLOADED $ALIGNIOLOADED );
+use vars qw(@ISA $SEQIOLOADED $ALIGNIOLOADED);
 use strict;
 use Data::Dumper;
+use Bio::Root::Root;
 use Bio::Tools::Run::EMBOSSacd;
-use base qw(Bio::Root::Root Bio::Tools::Run::WrapperBase);
+use Bio::Tools::Run::WrapperBase;
+@ISA = qw(Bio::Root::Root Bio::Tools::Run::WrapperBase);
 
 sub new {
   my($class, $args) = @_;
@@ -123,107 +134,107 @@ sub new {
 =cut
 
 sub run {
-	my ($self, $input) = @_;
-	$self->io->_io_cleanup();
-	# test input
-	$self->debug( Dumper($input) );
+    my ($self, $input) = @_;
+    $self->io->_io_cleanup();
+    # test input
+    $self->debug( Dumper($input) ) if $self->verbose > 0;
 
-	# parse ACD information
-	$self->acd if $self->verbose > 0;
+    #parse ACD information
+    $self->acd if $self->verbose > 0;
 
-	# collect the options into a string
-	my $option_string = '';
-	foreach my $attr (keys %{$input}) {
-		my $attr_name = substr($attr, 1) if substr($attr, 0, 1) =~ /\W/;
+    # collect the options into a string
+    my $option_string = '';
+    foreach my $attr (keys %{$input}) {
+	my $attr_name = substr($attr, 1) if substr($attr, 0, 1) =~ /\W/;
 
-		my $array = 0;
+	my $array = 0;
 
-		if( defined $input->{$attr} && ref($input->{$attr}) ) {
+	if( defined $input->{$attr} && ref($input->{$attr}) ) {
 
-			my (@pieces);
+	    my (@pieces);
 
-			if( $array = (ref($input->{$attr}) =~ /array/i) ) {
-				foreach my $s ( @{$input->{$attr}} ) {
-					@pieces = @{$input->{$attr}};
-				}
-			} else {
-				@pieces = ($input->{$attr});
-			}
-			if( ! defined $pieces[0] ) {
-				# we ignore for now
-				$self->warn("specified a parameter $attr with no value");
-				$input->{$attr} = undef;
-				return;
-			} elsif( $pieces[0]->isa('Bio::PrimarySeqI') ) {
-				unless(  $SEQIOLOADED ) { 
-					require Bio::SeqIO;
-					$SEQIOLOADED = 1;
-				}
-				my ($tfh,$tempfile) = $self->io->tempfile(-dir => $self->tempdir);
-				my $out = new Bio::SeqIO(-format => 'fasta',
-												 -fh     => $tfh);
-				foreach my $seq ( @pieces ) {
-					$out->write_seq($seq);
-				}
-				$out->close();
-				$input->{$attr} = $tempfile;
-				close($tfh);
-				undef $tfh;
-			} elsif( $pieces[0]->isa('Bio::Align::AlignI') ) {
-				unless(  $ALIGNIOLOADED ) { 
-					require Bio::AlignIO;
-					$ALIGNIOLOADED = 1;
-				}
-				my ($tfh,$tempfile) = $self->io->tempfile();
-				my $out = new Bio::AlignIO(-format => 'msf',
-													-fh     => $tfh);
-				foreach my $p ( @pieces ) {
-					$out->write_aln($p);
-				}
-				$input->{$attr} = $tempfile;
-				close($tfh);
-				undef $tfh;
-			}
+	    if( $array = (ref($input->{$attr}) =~ /array/i) ) {
+		foreach my $s ( @{$input->{$attr}} ) {
+		    @pieces = @{$input->{$attr}};
 		}
-
-		# check each argument against ACD
-		if ($self->verbose > 0) {
-
-			last unless defined $self->acd; # might not have the parser
-
-			$self->throw("Attribute [$attr] not recognized!\n")
-			  unless $self->acd->qualifier($attr);
+	    } else {
+		@pieces = ($input->{$attr});
+	    }
+	    if( ! defined $pieces[0] ) {
+		# we ignore for now
+		$self->warn("specified a parameter $attr with no value");
+		$input->{$attr} = undef;
+		return;
+	    } elsif( $pieces[0]->isa('Bio::PrimarySeqI') ) {
+		unless(  $SEQIOLOADED ) { 
+		    require Bio::SeqIO;
+		    $SEQIOLOADED = 1;
 		}
-
-		# print out debugging info
-		$self->debug("Input attr: ". $attr_name. " => ".
-						 $input->{$attr}. "\n");
-		$option_string .= " " . $attr;
-		$option_string .= " ". $input->{$attr}
-		  if defined $input->{$attr};
+		my ($tfh,$tempfile) = $self->io->tempfile(-dir => $self->tempdir);
+		my $out = new Bio::SeqIO(-format => 'fasta',
+					 -fh     => $tfh);
+		foreach my $seq ( @pieces ) {
+		    $out->write_seq($seq);
+		}
+		$out->close();
+		$input->{$attr} = $tempfile;
+		close($tfh);
+		undef $tfh;
+	    } elsif( $pieces[0]->isa('Bio::Align::AlignI') ) {
+		unless(  $ALIGNIOLOADED ) { 
+		    require Bio::AlignIO;
+		    $ALIGNIOLOADED = 1;
+		}
+		my ($tfh,$tempfile) = $self->io->tempfile();
+		my $out = new Bio::AlignIO(-format => 'msf',
+					   -fh     => $tfh);
+		foreach my $p ( @pieces ) {
+		    $out->write_aln($p);
+		}
+		$input->{$attr} = $tempfile;
+		close($tfh);
+		undef $tfh;
+	    }
 	}
 
-	# check mandatory attributes against given ones
+	# check each argument against ACD
 	if ($self->verbose > 0) {
-		last unless defined $self->acd; # might not have the parser
-		#	$self->acd->mandatory->print;
-		#	if ($self->name eq 'water') {
-		#	    print Dumper($self->acd->mandatory);
-		#	}
-		foreach my $attr (keys %{$self->acd->mandatory} ) {
-			last unless defined $self->acd; # might not have the parser
-			unless (defined $input->{$attr}) {
-				print "-" x 38, "\n", "MISSING MANDATORY ATTRIBUTE: $attr\n", 
-				  "-" x 38, "\n";
-				$self->acd->print($attr) and
-				  $self->throw("Program ". $self->name.
-									" needs attribute [$attr]!\n")
-			  }
-		}
+
+	    last unless defined $self->acd; # might not have the parser
+
+	    $self->throw("Attribute [$attr] not recognized!\n")
+		unless $self->acd->qualifier($attr);
 	}
-	my $runstring = join (' ', $self->name, $option_string, '-auto');
-	$self->debug( "Command line: ", $runstring, "\n"); 
-	return `$runstring`;
+
+	# print out debugging info
+	$self->debug("Input attr: ". $attr_name. " => ".
+		     $input->{$attr}. "\n");
+	$option_string .= " " . $attr;
+	$option_string .= " ". $input->{$attr}
+	   if $input->{$attr};
+    }
+
+    #check mandatory attributes against given ones
+    if ($self->verbose > 0) {
+	last unless defined $self->acd; # might not have the parser
+#	$self->acd->mandatory->print;
+#	if ($self->name eq 'water') {
+#	    print Dumper($self->acd->mandatory);
+#	}
+	foreach my $attr (keys %{$self->acd->mandatory} ) {
+	    last unless defined $self->acd; # might not have the parser
+	    unless ($input->{$attr}) {
+		print "-" x 38, "\n", "MISSING MANDATORY ATTRIBUTE: $attr\n", 
+		    "-" x 38, "\n";
+		$self->acd->print($attr) and
+		$self->throw("Program ". $self->name.
+			 " needs attribute [$attr]!\n")
+	    }
+	}
+    }
+    my $runstring = join (' ', $self->name, $option_string, '-auto');
+    print STDERR "Command line: ", $runstring, "\n" if $self->verbose > 0;
+    return `$runstring`;
 }
 
 =head2 acd
@@ -302,6 +313,7 @@ sub descr {
 
            If the application is assigned into a subgroup
            use l<subgroup> to get it.
+
  Throws  : 
  Returns : string, group name
  Args    : group string
@@ -337,53 +349,7 @@ sub subgroup {
     return $self->{'_subgroup'};
 }
 
-=head2 program_dir
 
- Title   : program_dir
- Usage   :
- Function: Required by WrapperBase
- Throws  :
- Returns : Name of directory with EMBOSS programs
- Args    :
 
-=cut
-
-sub program_dir {
-	return Bio::Root::IO->catfile($ENV{EMBOSS_ACDROOT});
-}
-
-=head2 program_path
-
- Title   : program_path
- Usage   :
- Function: Required by WrapperBase
- Throws  :
- Returns : Full path of program
- Args    :
-
-=cut
-
-sub program_path {
-	my $self = shift;
-	my $name = $self->{_name};
-	my $dir = Bio::Root::IO->catfile($ENV{EMBOSS_ACDROOT});
-	return "$dir/$name";
-}
-
-=head2 executable
-
- Title   : executable
- Usage   :
- Function: Required by WrapperBase
- Throws  :
- Returns : Name of program
- Args    :
-
-=cut
-
-sub executable {
-	my $self = shift;
-	$self->{_name};
-}
 
 1;
