@@ -1,8 +1,8 @@
-# $Id: Yn00.pm,v 1.21 2006/07/01 15:34:53 mauricio Exp $
+# Yn00.pm,v 1.3 2002/06/21 12:57:49 heikki Exp
 #
 # BioPerl module for Bio::Tools::Run::Phylo::PAML::Yn00
 #
-# Cared for by Jason Stajich <jason-AT-bioperl_DOT_org>
+# Cared for by Jason Stajich <jason@bioperl.org>
 #
 # Copyright Jason Stajich
 #
@@ -54,19 +54,21 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via the
-web:
+of the bugs and their resolution. Bug reports can be submitted via
+email or the web:
 
+  bioperl-bugs@bioperl.org
+  http://bioperl.org/bioperl-bugs/
 
 =head1 AUTHOR - Jason Stajich
 
-Email jason-at-bioperl.org
+Email jason@bioperl.org
 
 =head1 CONTRIBUTORS
 
@@ -108,7 +110,7 @@ BEGIN {
     $MINNAMELEN = 25;
     $PROGRAMNAME = 'yn00'  . ($^O =~ /mswin/i ?'.exe':'');
     if( defined $ENV{'PAMLDIR'} ) {
-	$PROGRAM = Bio::Root::IO->catfile($ENV{'PAMLDIR'},$PROGRAMNAME);
+	$PROGRAM = Bio::Root::IO->catdir($ENV{'PAMLDIR'},$PROGRAMNAME);
     }
     # valid values for parameters, the default one is always
     # the first one in the array
@@ -144,7 +146,7 @@ BEGIN {
 =head2 program_name
 
  Title   : program_name
- Usage   : $yn00->program_name()
+ Usage   : >program_name()
  Function: holds the program name
  Returns:  string
  Args    : None
@@ -152,13 +154,13 @@ BEGIN {
 =cut
 
 sub program_name {
-    return $PROGRAMNAME;
+            return 'yn00';
 }
 
 =head2 program_dir
 
  Title   : program_dir
- Usage   : $yn00->program_dir()
+ Usage   : ->program_dir()
  Function: returns the program directory, obtiained from ENV variable.
  Returns:  string
  Args    :
@@ -213,10 +215,10 @@ sub new {
 =cut
 
 sub run{
-   my ($self,$aln) = @_;
-   ($aln) ||= $self->alignment();
+   my ($self) = @_;
+   my ($aln) = $self->alignment();
    if( ! $aln ) { 
-       $self->warn("must have supplied a valid alignment file in order to run yn00");
+       $self->warn("must have supplied a valid aligment file in order to run yn00");
        return 0;
    }
    my ($tmpdir) = $self->tempdir();
