@@ -149,16 +149,17 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org                     - General discussion
+  http://bio.perl.org/MailList.html         - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+ the bugs and their resolution.  Bug reports can be submitted via
+ email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bio.perl.org
+  http://bugzilla.bioperl.org/
 
 =head1 AUTHOR - Shawn Hoon 
 
@@ -190,7 +191,7 @@ use Bio::TreeIO;
 use Bio::Root::Root;
 use Bio::Root::IO;
 use Bio::Tools::Run::Phylo::Phylip::Base;
-use Bio::Tools::Run::Phylo::Phylip::PhylipConf qw(%Menu);
+use Bio::Tools::Run::Phylo::Phylip::PhylipConf;
 
 use Cwd;
 			    
@@ -520,7 +521,7 @@ sub _setparams {
     my $param_string = "";
     my $type ="";
     my $version = $self->version;
-    my %menu = %{$Menu{$version}->{'NEIGHBOR'}};
+    my %menu = %{$Bio::Tools::Run::Phylo::Phylip::PhylipConf::Menu{$version}->{'NEIGHBOR'}};
 
     foreach  my $attr ( @NEIGHBOR_PARAMS) {
     	$value = $self->$attr();
