@@ -1,4 +1,4 @@
-# $Id: seqgen.pm,v 1.8 2006/07/04 22:23:35 mauricio Exp $
+# $Id: seqgen.pm,v 1.3 2003/06/14 06:05:24 letondal Exp $
 # BioPerl module for Bio::Tools::Run::PiseApplication::seqgen
 #
 # Cared for by Catherine Letondal <letondal@pasteur.fr>
@@ -51,66 +51,51 @@ Bio::Tools::Run::PiseApplication::seqgen
 		datasets (Integer)
 			number of simulated datasets per tree (-n)
 
-		partition_numb (Integer)
-			Number of partitions for each dataset (-p)
-
-		scale_branch (Float)
+		scale_branch (Integer)
 			Scale branch lengths  (a decimal number greater > 0) (-s)
 
-		scale_tree (Float)
+		scale_tree (Integer)
 			total tree scale  (a decimal number greater > 0) [default = use branch lengths] (-d)
 
-		rate1 (Float)
+		rate1 (Integer)
 			rates for codon position heterogeneity, first position (enter a decimal number) (-c)
 
-		rate2 (Float)
+		rate2 (Integer)
 			rates for codon position heterogeneity, second position (enter a decimal number)
 
-		rate3 (Float)
+		rate3 (Integer)
 			rates for codon position heterogeneity, third position (enter a decimal number)
 
-		shape (Float)
+		shape (Integer)
 			shape of the gamma distribution to use  with  gamma rate heterogeneity (a decimal  number) (-a)
 
 		categories (Integer)
 			number of categories  for  the  discrete gamma  rate  heterogeneity model (>2 and < 32) (-g)
 
-		invar_site (Float)
-			proportion of sites that should be invariable (a real	      number >= 0.0 and < 1.0) (-i)
-
-		freqA (Float)
+		freqA (Integer)
 			relative frequencies of the A nucleotide (a decimal number) (-f)
 
-		freqC (Float)
+		freqC (Integer)
 			relative frequencies of the C nucleotide (a decimal number)
 
-		freqG (Float)
+		freqG (Integer)
 			relative frequencies of the G nucleotide (a decimal number)
 
-		freqT (Float)
+		freqT (Integer)
 			relative frequencies of the T nucleotide (a decimal number)
 
-		transratio (Float)
+		transratio (Integer)
 			transition transversion ratio (TS/TV) (this is only valid when either the HKY or F84 model has been selected) (-t)
 
 		matrix (String)
 			6 values  for  the general reversable  model's rate matrix (ACTG x ACTG) (REV model), separated by commas (-r)
 
-		random_seed (Integer)
-			random number seed (-z)
-
-		phylip (Excl)
-			output file format [default : standard PHYLIP output]
+		phylip (Switch)
+			Relaxed PHYLIP output [default : standard PHYLIP output] (-p)
 
 		quiet (Switch)
 			non verbose output (-q)
 
-		write_ancest (Switch)
-			write the ancestral sequences (-wa)
-
-		write_sites (Switch)
-			write the sites rates (-wr)
-
 		input_seq (Integer)
 			Ancestral Sequence number (-k)
 
@@ -122,16 +107,17 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bioperl.org/MailList.shtml  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via the
-web:
+of the bugs and their resolution. Bug reports can be submitted via
+email or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bioperl.org/bioperl-bugs/
 
 =head1 AUTHOR
 
@@ -210,11 +196,6 @@ sub new {
 
     $self->{OPT_EMAIL}   = 0;
 
-    $self->{CATEGORIES}   =  [  
-
-         "phylogeny",
-  ];
-
     $self->{AUTHORS}   = "A. Rambaut, N. C. Grassly";
 
     $self->{REFERENCE}   = [
@@ -242,7 +223,6 @@ sub new {
 	"model", 	# model of nucleotide substitution
 	"length", 	# sequence length (-l)
 	"datasets", 	# number of simulated datasets per tree (-n)
-	"partition_numb", 	# Number of partitions for each dataset (-p)
 	"scale_branch", 	# Scale branch lengths  (a decimal number greater > 0) (-s)
 	"scale_tree", 	# total tree scale  (a decimal number greater > 0) [default = use branch lengths] (-d)
 	"rate1", 	# rates for codon position heterogeneity, first position (enter a decimal number) (-c)
@@ -250,20 +230,16 @@ sub new {
 	"rate3", 	# rates for codon position heterogeneity, third position (enter a decimal number)
 	"shape", 	# shape of the gamma distribution to use  with  gamma rate heterogeneity (a decimal  number) (-a)
 	"categories", 	# number of categories  for  the  discrete gamma  rate  heterogeneity model (>2 and < 32) (-g)
-	"invar_site", 	# proportion of sites that should be invariable (a real	      number >= 0.0 and < 1.0) (-i)
 	"freqA", 	# relative frequencies of the A nucleotide (a decimal number) (-f)
 	"freqC", 	# relative frequencies of the C nucleotide (a decimal number)
 	"freqG", 	# relative frequencies of the G nucleotide (a decimal number)
 	"freqT", 	# relative frequencies of the T nucleotide (a decimal number)
 	"transratio", 	# transition transversion ratio (TS/TV) (this is only valid when either the HKY or F84 model has been selected) (-t)
 	"matrix", 	# 6 values  for  the general reversable  model's rate matrix (ACTG x ACTG) (REV model), separated by commas (-r)
-	"random_seed", 	# random number seed (-z)
 	"outfile",
 	"output", 	# Output parameters
-	"phylip", 	# output file format [default : standard PHYLIP output]
+	"phylip", 	# Relaxed PHYLIP output [default : standard PHYLIP output] (-p)
 	"quiet", 	# non verbose output (-q)
-	"write_ancest", 	# write the ancestral sequences (-wa)
-	"write_sites", 	# write the sites rates (-wr)
 	"input", 	# Input parameters
 	"input_seq", 	# Ancestral Sequence number (-k)
 
@@ -276,28 +252,23 @@ sub new {
 	"model" => 'Excl',
 	"length" => 'Integer',
 	"datasets" => 'Integer',
-	"partition_numb" => 'Integer',
-	"scale_branch" => 'Float',
-	"scale_tree" => 'Float',
-	"rate1" => 'Float',
-	"rate2" => 'Float',
-	"rate3" => 'Float',
-	"shape" => 'Float',
+	"scale_branch" => 'Integer',
+	"scale_tree" => 'Integer',
+	"rate1" => 'Integer',
+	"rate2" => 'Integer',
+	"rate3" => 'Integer',
+	"shape" => 'Integer',
 	"categories" => 'Integer',
-	"invar_site" => 'Float',
-	"freqA" => 'Float',
-	"freqC" => 'Float',
-	"freqG" => 'Float',
-	"freqT" => 'Float',
-	"transratio" => 'Float',
+	"freqA" => 'Integer',
+	"freqC" => 'Integer',
+	"freqG" => 'Integer',
+	"freqT" => 'Integer',
+	"transratio" => 'Integer',
 	"matrix" => 'String',
-	"random_seed" => 'Integer',
 	"outfile" => 'Results',
 	"output" => 'Paragraph',
-	"phylip" => 'Excl',
+	"phylip" => 'Switch',
 	"quiet" => 'Switch',
-	"write_ancest" => 'Switch',
-	"write_sites" => 'Switch',
 	"input" => 'Paragraph',
 	"input_seq" => 'Integer',
 
@@ -321,9 +292,6 @@ sub new {
 	"datasets" => {
 		"perl" => '(defined $value && $value ne $vdef)? " -n $value":""',
 	},
-	"partition_numb" => {
-		"perl" => '($value)? " -p $value":""',
-	},
 	"scale_branch" => {
 		"perl" => '(defined $value)? " -s $value":""',
 	},
@@ -345,9 +313,6 @@ sub new {
 	"categories" => {
 		"perl" => '(defined $value)? " -g $value":""',
 	},
-	"invar_site" => {
-		"perl" => '(defined $value and $value != $vdef)? " -i $value":""',
-	},
 	"freqA" => {
 		"perl" => '(defined $value)? " -f $freqA,$freqC,$freqG,$freqT":""',
 	},
@@ -366,25 +331,16 @@ sub new {
 	"matrix" => {
 		"perl" => '($value)? " -r $value":""',
 	},
-	"random_seed" => {
-		"perl" => '($value)? "-z $value":""',
-	},
 	"outfile" => {
 	},
 	"output" => {
 	},
 	"phylip" => {
-		"perl" => '($value)? " -o$value":""',
+		"perl" => '($value)? " -p":""',
 	},
 	"quiet" => {
 		"perl" => '($value)? " -q":""',
 	},
-	"write_ancest" => {
-		"perl" => '($value)? " -wa":""',
-	},
-	"write_sites" => {
-		"perl" => '($value)? " -wr":""',
-	},
 	"input" => {
 	},
 	"input_seq" => {
@@ -408,7 +364,6 @@ sub new {
 	"model" => 1,
 	"length" => 1,
 	"datasets" => 1,
-	"partition_numb" => 1,
 	"scale_branch" => 1,
 	"scale_tree" => 1,
 	"rate1" => 1,
@@ -416,7 +371,6 @@ sub new {
 	"rate3" => 1,
 	"shape" => 1,
 	"categories" => 1,
-	"invar_site" => 1,
 	"freqA" => 1,
 	"freqC" => 1,
 	"freqG" => 1,
@@ -432,12 +386,11 @@ sub new {
 
     $self->{BY_GROUP_PARAMETERS}  = [
 	"seqgen",
-	"random_seed",
-	"control",
 	"outfile",
+	"control",
 	"output",
-	"write_ancest",
-	"write_sites",
+	"length",
+	"datasets",
 	"scale_branch",
 	"scale_tree",
 	"rate1",
@@ -445,7 +398,6 @@ sub new {
 	"rate3",
 	"shape",
 	"categories",
-	"invar_site",
 	"freqA",
 	"freqC",
 	"freqG",
@@ -453,11 +405,8 @@ sub new {
 	"transratio",
 	"matrix",
 	"model",
-	"length",
 	"phylip",
 	"quiet",
-	"datasets",
-	"partition_numb",
 	"input",
 	"input_seq",
 	"tree",
@@ -475,7 +424,6 @@ sub new {
 	"model" => 0,
 	"length" => 0,
 	"datasets" => 0,
-	"partition_numb" => 0,
 	"scale_branch" => 0,
 	"scale_tree" => 0,
 	"rate1" => 0,
@@ -483,20 +431,16 @@ sub new {
 	"rate3" => 0,
 	"shape" => 0,
 	"categories" => 0,
-	"invar_site" => 0,
 	"freqA" => 0,
 	"freqC" => 0,
 	"freqG" => 0,
 	"freqT" => 0,
 	"transratio" => 0,
 	"matrix" => 0,
-	"random_seed" => 0,
 	"outfile" => 0,
 	"output" => 0,
 	"phylip" => 0,
 	"quiet" => 0,
-	"write_ancest" => 0,
-	"write_sites" => 0,
 	"input" => 0,
 	"input_seq" => 0,
 
@@ -509,7 +453,6 @@ sub new {
 	"model" => 0,
 	"length" => 0,
 	"datasets" => 0,
-	"partition_numb" => 0,
 	"scale_branch" => 0,
 	"scale_tree" => 0,
 	"rate1" => 0,
@@ -517,20 +460,16 @@ sub new {
 	"rate3" => 0,
 	"shape" => 0,
 	"categories" => 0,
-	"invar_site" => 0,
 	"freqA" => 0,
 	"freqC" => 0,
 	"freqG" => 0,
 	"freqT" => 0,
 	"transratio" => 0,
 	"matrix" => 0,
-	"random_seed" => 0,
 	"outfile" => 0,
 	"output" => 0,
 	"phylip" => 0,
 	"quiet" => 0,
-	"write_ancest" => 0,
-	"write_sites" => 0,
 	"input" => 0,
 	"input_seq" => 0,
 
@@ -543,7 +482,6 @@ sub new {
 	"model" => 0,
 	"length" => 0,
 	"datasets" => 0,
-	"partition_numb" => 0,
 	"scale_branch" => 0,
 	"scale_tree" => 0,
 	"rate1" => 0,
@@ -551,20 +489,16 @@ sub new {
 	"rate3" => 0,
 	"shape" => 0,
 	"categories" => 0,
-	"invar_site" => 0,
 	"freqA" => 0,
 	"freqC" => 0,
 	"freqG" => 0,
 	"freqT" => 0,
 	"transratio" => 0,
 	"matrix" => 0,
-	"random_seed" => 0,
 	"outfile" => 0,
 	"output" => 0,
 	"phylip" => 0,
 	"quiet" => 0,
-	"write_ancest" => 0,
-	"write_sites" => 0,
 	"input" => 0,
 	"input_seq" => 0,
 
@@ -577,7 +511,6 @@ sub new {
 	"model" => "model of nucleotide substitution",
 	"length" => "sequence length (-l)",
 	"datasets" => "number of simulated datasets per tree (-n)",
-	"partition_numb" => "Number of partitions for each dataset (-p)",
 	"scale_branch" => "Scale branch lengths  (a decimal number greater > 0) (-s)",
 	"scale_tree" => "total tree scale  (a decimal number greater > 0) [default = use branch lengths] (-d)",
 	"rate1" => "rates for codon position heterogeneity, first position (enter a decimal number) (-c)",
@@ -585,20 +518,16 @@ sub new {
 	"rate3" => "rates for codon position heterogeneity, third position (enter a decimal number)",
 	"shape" => "shape of the gamma distribution to use  with  gamma rate heterogeneity (a decimal  number) (-a)",
 	"categories" => "number of categories  for  the  discrete gamma  rate  heterogeneity model (>2 and < 32) (-g)",
-	"invar_site" => "proportion of sites that should be invariable (a real	      number >= 0.0 and < 1.0) (-i)",
 	"freqA" => "relative frequencies of the A nucleotide (a decimal number) (-f)",
 	"freqC" => "relative frequencies of the C nucleotide (a decimal number)",
 	"freqG" => "relative frequencies of the G nucleotide (a decimal number)",
 	"freqT" => "relative frequencies of the T nucleotide (a decimal number)",
 	"transratio" => "transition transversion ratio (TS/TV) (this is only valid when either the HKY or F84 model has been selected) (-t)",
 	"matrix" => "6 values  for  the general reversable  model's rate matrix (ACTG x ACTG) (REV model), separated by commas (-r)",
-	"random_seed" => "random number seed (-z)",
 	"outfile" => "",
 	"output" => "Output parameters",
-	"phylip" => "output file format [default : standard PHYLIP output]",
+	"phylip" => "Relaxed PHYLIP output [default : standard PHYLIP output] (-p)",
 	"quiet" => "non verbose output (-q)",
-	"write_ancest" => "write the ancestral sequences (-wa)",
-	"write_sites" => "write the sites rates (-wr)",
 	"input" => "Input parameters",
 	"input_seq" => "Ancestral Sequence number (-k)",
 
@@ -611,7 +540,6 @@ sub new {
 	"model" => 0,
 	"length" => 0,
 	"datasets" => 0,
-	"partition_numb" => 0,
 	"scale_branch" => 0,
 	"scale_tree" => 0,
 	"rate1" => 0,
@@ -619,20 +547,16 @@ sub new {
 	"rate3" => 0,
 	"shape" => 0,
 	"categories" => 0,
-	"invar_site" => 0,
 	"freqA" => 0,
 	"freqC" => 0,
 	"freqG" => 0,
 	"freqT" => 0,
 	"transratio" => 0,
 	"matrix" => 0,
-	"random_seed" => 0,
 	"outfile" => 0,
 	"output" => 0,
 	"phylip" => 0,
 	"quiet" => 0,
-	"write_ancest" => 0,
-	"write_sites" => 0,
 	"input" => 0,
 	"input_seq" => 0,
 
@@ -640,10 +564,9 @@ sub new {
 
     $self->{VLIST}  = {
 
-	"control" => ['model','length','datasets','partition_numb','scale_branch','scale_tree','rate1','rate2','rate3','shape','categories','invar_site','freqA','freqC','freqG','freqT','transratio','matrix','random_seed',],
+	"control" => ['model','length','datasets','scale_branch','scale_tree','rate1','rate2','rate3','shape','categories','freqA','freqC','freqG','freqT','transratio','matrix',],
 	"model" => ['F84','F84','HKY','HKY','REV','REV',],
-	"output" => ['phylip','quiet','write_ancest','write_sites',],
-	"phylip" => ['p','PHYLIP','r','relaxed PHYLIP','n','NEXUS',],
+	"output" => ['phylip','quiet',],
 	"input" => ['input_seq',],
     };
 
@@ -659,8 +582,6 @@ sub new {
 	"model" => 'F84',
 	"length" => '1000',
 	"datasets" => '1',
-	"invar_site" => '0.0',
-	"phylip" => 'p',
 
     };
 
@@ -671,7 +592,6 @@ sub new {
 	"model" => { "perl" => '1' },
 	"length" => { "perl" => '1' },
 	"datasets" => { "perl" => '1' },
-	"partition_numb" => { "perl" => '1' },
 	"scale_branch" => { "perl" => '1' },
 	"scale_tree" => { "perl" => '1' },
 	"rate1" => { "perl" => '1' },
@@ -679,20 +599,16 @@ sub new {
 	"rate3" => { "perl" => '1' },
 	"shape" => { "perl" => '1' },
 	"categories" => { "perl" => '1' },
-	"invar_site" => { "perl" => '1' },
 	"freqA" => { "perl" => '1' },
 	"freqC" => { "perl" => '1' },
 	"freqG" => { "perl" => '1' },
 	"freqT" => { "perl" => '1' },
 	"transratio" => { "perl" => '1' },
 	"matrix" => { "perl" => '1' },
-	"random_seed" => { "perl" => '1' },
 	"outfile" => { "perl" => '1' },
 	"output" => { "perl" => '1' },
 	"phylip" => { "perl" => '1' },
 	"quiet" => { "perl" => '1' },
-	"write_ancest" => { "perl" => '1' },
-	"write_sites" => { "perl" => '1' },
 	"input" => { "perl" => '1' },
 	"input_seq" => { "perl" => '1' },
 
@@ -719,11 +635,6 @@ sub new {
 			'defined $categories && ($categories < 2 || $$categories > 32)' => "enter an integer number between 2 and 32",
 		},
 	},
-	"invar_site" => {
-		"perl" => {
-			'defined $value && ($value < 0.0 || $value >= 1.0)' => "enter a real number >= 0.0 and < 1.0 ",
-		},
-	},
 	"freqA" => {
 		"perl" => {
 			'((defined $freqC || defined $freqG || defined $freqT) && ! (defined $freqA))' => "you must give the frequencies for the 4 nucleotides",
@@ -781,7 +692,6 @@ sub new {
 	"model" => 0,
 	"length" => 0,
 	"datasets" => 0,
-	"partition_numb" => 0,
 	"scale_branch" => 0,
 	"scale_tree" => 0,
 	"rate1" => 0,
@@ -789,20 +699,16 @@ sub new {
 	"rate3" => 0,
 	"shape" => 0,
 	"categories" => 0,
-	"invar_site" => 0,
 	"freqA" => 0,
 	"freqC" => 0,
 	"freqG" => 0,
 	"freqT" => 0,
 	"transratio" => 0,
 	"matrix" => 0,
-	"random_seed" => 0,
 	"outfile" => 0,
 	"output" => 0,
 	"phylip" => 0,
 	"quiet" => 0,
-	"write_ancest" => 0,
-	"write_sites" => 0,
 	"input" => 0,
 	"input_seq" => 0,
 
@@ -815,7 +721,6 @@ sub new {
 	"model" => 0,
 	"length" => 0,
 	"datasets" => 0,
-	"partition_numb" => 0,
 	"scale_branch" => 0,
 	"scale_tree" => 0,
 	"rate1" => 0,
@@ -823,20 +728,16 @@ sub new {
 	"rate3" => 0,
 	"shape" => 0,
 	"categories" => 0,
-	"invar_site" => 0,
 	"freqA" => 0,
 	"freqC" => 0,
 	"freqG" => 0,
 	"freqT" => 0,
 	"transratio" => 0,
 	"matrix" => 0,
-	"random_seed" => 0,
 	"outfile" => 0,
 	"output" => 0,
 	"phylip" => 0,
 	"quiet" => 0,
-	"write_ancest" => 0,
-	"write_sites" => 0,
 	"input" => 0,
 	"input_seq" => 0,
 
@@ -863,9 +764,6 @@ sub new {
 	"datasets" => [
 		"This option specifies how many separate datasets should be simulated for each tree in the tree file.",
 	],
-	"partition_numb" => [
-		"Number of partion specifies how many	      partitions of each data set should be simulated. each	      partition must have its own tree and number specifying how	      many sites are in partition. Multiple sets of trees are	      being inputed with varying numbers of partitions, then this	      should specify the maximum number of partitions that will be	      required",
-	],
 	"scale_branch" => [
 		"This option allows the user to set a value with which to scale the branch lengths in order to make them equal the expected number of substitutions per site for each branch. Basically Seq-Gen multiplies each branch length by this value.",
 		"For example if you give an value of 0.5 then each branch length would be halved before using it to simulate the sequences.",
@@ -883,9 +781,6 @@ sub new {
 	"categories" => [
 		"Using this option the user may specify the number of categories for the discrete gamma rate heterogeneity model. The default is no site-specific rate heterogeneity (or the continuous model if only the -a option is specified.",
 	],
-	"invar_site" => [
-		"specify the proportion of sites that should	      be invariable. These sites will be chosen randomly with this	      expected frequency. The default is no invariable sites.	      Invariable sites are sites thar cannot change as opposed to	      sites wich don\'t exhibit any changes due to channce (and	      prhaps a low rate).",
-	],
 	"freqA" => [
 		"This option is used to specify the relative frequencies of the four nucleotides. By default, Seq-Gen will assume these to be equal. If the given values don\'t sum to 1.0 then they will be scaled so that they do.",
 	],
@@ -896,15 +791,6 @@ sub new {
 		"This option allows the user to set 6 values for the general reversable model\'s rate matrix. This is only valid when either the REV model has been selected.",
 		"The values are six decimal numbers for the rates of transition from A to C, A to G, A to T, C to G, C to T and G to T respectively, separated by spaces or commas. The matrix is symmetrical so the reverse transitions equal the ones set (e.g. C to A equals A to C) and therefore only six values need be set. These values will be scaled such that the last value (G to T) is 1.0 and the others are set relative to this.",
 	],
-	"random_seed" => [
-		"This option allows to specify a seed for the random number	  generator. Using the same seed (with the same input) will result	  in identical simulated datasets. This is useful because you can	  recreate a set of simulations, you must use exactly the same	  model options",
-	],
-	"write_ancest" => [
-		"This option allows to obtain the sequences for each	      of the internal nodes in the tree.                The sequences are written out along with the sequencees for	      the tips of the tree in relaxed PHYLIP format.                 ",
-	],
-	"write_sites" => [
-		"This option allows to obtain the relative rate of	      substitution for each sites as used in each simulation. This	      will go to sderr and will be produced for each replicate simulation.                 ",
-	],
 	"input_seq" => [
 		"This option allows the user to use a supplied sequence as the ancestral sequence at the root (otherwise a random sequence is used). The value is an integer number greater than zero which refers to one of the sequences supplied as input with the tree.",
 		"Method: The user can supply a sequence alignment as input, as well as the trees. This should be in relaxed PHYLIP format. The trees can then be placed in this file at the end, after a line stating how many trees there are.The file may look like this: ",
