@@ -1,4 +1,4 @@
-# $Id: Profile.pm,v 1.14 2006/07/04 22:23:31 mauricio Exp $
+# $Id: Profile.pm,v 1.10 2003/05/26 04:02:47 shawnh Exp $
 # BioPerl module for Profile
 # Copyright Balamurugan Kumarasamy
 #
@@ -29,20 +29,21 @@ Bio::Tools::Run::Profile
 
 =head2 Mailing Lists
 
-User feedback is an integral part of the evolution of this and other
-Bioperl modules. Send your comments and suggestions preferably to one
-of the Bioperl mailing lists.  Your participation is much appreciated.
+ User feedback is an integral part of the evolution of this and other
+ Bioperl modules. Send your comments and suggestions preferably to one
+ of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+ bioperl-l@bioperl.org          - General discussion
+ http://bio.perl.org/MailList.html             - About the mailing lists
 
 =head2 Reporting Bugs
 
-Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+ Report bugs to the Bioperl bug tracking system to help us keep track
+ the bugs and their resolution.  Bug reports can be submitted via
+ email or the web:
 
-  http://bugzilla.open-bio.org/
+ bioperl-bugs@bio.perl.org
+ http://bio.perl.org/bioperl-bugs/
 
 =head1 AUTHOR - Balamurugan Kumarasamy
 
