@@ -1,4 +1,4 @@
-# $Id: Seg.pm,v 1.16 2006/07/04 22:23:31 mauricio Exp $
+# $Id: Seg.pm,v 1.9 2003/03/28 22:42:07 jason Exp $
 # Copyright Balamurugan Kumarasamy
 # You may distribute this module under the same terms as perl itself
 #  POD documentation - main docs before the code
@@ -21,28 +21,30 @@ Bio::Tools::Run::Seg - Object for identifying low complexity
 
 =head1 DESCRIPTION
 
-Seg is a program which identifies low complexity regions in proteins.
-It was developed by Wootton and Federhen at NCBI.
+ Seg is a low complexity region (in protein) identifying program
+ developed by Wootton and Federhen at the National Center for
+ Biotechnology Information (NCBI)
 
 =head1 FEEDBACK
 
 =head2 Mailing Lists
 
-User feedback is an integral part of the evolution of this and other
-Bioperl modules. Send your comments and suggestions preferably to one
-of the Bioperl mailing lists.  Your participation is much appreciated.
+ User feedback is an integral part of the evolution of this and other
+ Bioperl modules. Send your comments and suggestions preferably to one
+ of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+ bioperl-l@bioperl.org          - General discussion
+ http://bio.perl.org/MailList.html             - About the mailing lists
 
 
 =head2 Reporting Bugs
 
-Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+ Report bugs to the Bioperl bug tracking system to help us keep track
+ the bugs and their resolution.  Bug reports can be submitted via
+ email or the web:
 
-  http://bugzilla.open-bio.org/
+ bioperl-bugs@bio.perl.org
+ http://bio.perl.org/bioperl-bugs/
 
 =head1 AUTHOR - Bala
 
@@ -50,8 +52,8 @@ web:
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object
-methods. Internal methods are usually preceded with a _
+ The rest of the documentation details each of the object
+ methods. Internal methods are usually preceded with a _
 
 =cut
 
@@ -77,7 +79,7 @@ BEGIN {
 =head2 program_name
 
  Title   : program_name
- Usage   : $factory->program_name()
+ Usage   : $factory>program_name()
  Function: holds the program name
  Returns:  string
  Args    : None
@@ -92,9 +94,9 @@ sub program_name {
 
  Title   : program_dir
  Usage   : $factory->program_dir(@params)
- Function: returns the program directory, obtained from ENV variable.
- Returns : string, or undef if $SEGDIR not in ENV
- Args    : None
+ Function: returns the program directory, obtiained from ENV variable.
+ Returns:  string
+ Args    :
 
 =cut
 
@@ -182,7 +184,7 @@ sub run{
 
         $self->_input($seq);
 
-        @feats = $self->_run();
+         @feats = $self->_run();
 
     }
 
@@ -194,7 +196,7 @@ sub run{
 
  Title   :   _input
  Usage   :   obj->_input($seqFile)
- Function:   Internal (not to be used directly)
+ Function:   Internal(not to be used directly)
  Returns :
  Args    :
 
@@ -213,9 +215,9 @@ sub _input {
 
  Title   :   _run
  Usage   :   $obj->_run()
- Function:   Internal (not to be used directly)
+ Function:   Internal(not to be used directly)
  Returns :   An array of Bio::SeqFeature::Generic objects
- Args    :   None
+ Args    :
 
 =cut
 
@@ -226,7 +228,7 @@ sub _run {
      my $str =$self->executable." ".$self->_input." -l > ".$outfile;
      my $status = system($str);
      $self->throw( "Seg call ($str) crashed: $? \n") unless $status==0;
-     
+
      my $filehandle;
      if (ref ($outfile) !~ /GLOB/) {
         open (SEG, "<".$outfile) or $self->throw ("Couldn't open file ".$outfile.": $!\n");
@@ -256,9 +258,9 @@ sub _run {
 
  Title   :   _writeSeqFile
  Usage   :   obj->_writeSeqFile($seq)
- Function:   Internal (not to be used directly)
- Returns :   string - Fasta filename to which $seq was written
- Args    :   Bio::Seq object
+ Function:   Internal(not to be used directly)
+ Returns :
+ Args    :
 
 =cut
 
