@@ -116,16 +116,17 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists. Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+  bioperl-l@bioperl.org              - General discussion
+  http://bio.perl.org/MailList.html  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-the bugs and their resolution.  Bug reports can be submitted via the
-web:
+the bugs and their resolution.  Bug reports can be submitted via email
+or the web:
 
-  http://bugzilla.open-bio.org/
+  bioperl-bugs@bioperl.org
+  http://bio.perl.org/bioperl-bugs/
 
 =head1 AUTHOR - Shawn Hoon
 
@@ -376,16 +377,29 @@ sub _generate_families {
               my %taxon;
               $taxon_str=~s/=;/=undef;/g if $taxon_str;
               %taxon = map{split '=',$_}split';',$taxon_str if $taxon_str;
-              my $name = $taxon{'taxon_common_name'};
-              my @classification = $taxon{'taxon_classification'} ? split(':',$taxon{'taxon_classification'}) : ();
-              my $tax_id = $taxon{'taxon_id'};
-              my $sub_species = $taxon{'taxon_sub_species'};
+              my $name = $taxon{'taxon_common_name'} eq 'undef' ?
+                  undef : $taxon{'taxon_common_name'}
+                        if $taxon{'taxon_common_name'};
+              my @classification = $taxon{'taxon_classification'} eq 'undef' ?
+                  undef : split(':',$taxon{'taxon_classification'})
+                        if $taxon{'taxon_classification'};
+              my $tax_id = $taxon{'taxon_id'} eq 'undef' ? 
+                  undef : $taxon{'taxon_id'} if $taxon{'taxon_id'};
+              my $sub_species = $taxon{'taxon_sub_species'} eq 'undef'?
+                  undef : $taxon{'taxon_sub_species'} if $taxon{'taxon_sub_species'} ;
 
-              my $species = Bio::Species->new();
-              $species->common_name($name) if $name; #*** should this actually be scientific_name() ?
-              $species->sub_species($sub_species) if $sub_species;
-              $species->ncbi_taxid($tax_id) if $tax_id;
-              $species->classification(@classification) if @classification;
+              my $species;
+
+              eval {
+                  $species = Bio::Species->new( -classification=>\@classification);
+              };
+              if($@){
+                $self->warn("Problems creating Species $@");
+                next;
+              }
+              $species->common_name($name);
+              $species->sub_species($sub_species);
+              $species->ncbi_taxid($tax_id);
               $mem->species($species); 
 
               push @mem, $mem;
@@ -910,20 +924,19 @@ sub _parse_mcl {
   my $i =-1;
   my $start;
   my (@cluster,@out);
-  while(<MCL>) {
-      if ($start) {
-	  chomp($_);
-	  $cluster[$i] = join(" ",$cluster[$i],"$_");
-      }
-      if(/^\d+/){
-	  $start = 1;
-	  $i++;
-	  $cluster[$i] = join(" ",$cluster[$i] || '',"$_");
-      }
-      if (/\$$/){
-	  $start = 0;
-      }
-      last if /^\(mclruninfo/;
+  while(<MCL>){
+    if ($start) {
+      chomp($_);
+      $cluster[$i] = join(" ",$cluster[$i],"$_");
+    }
+    if(/^\d+/){
+      $start = 1;
+      $i++;
+      $cluster[$i] = join(" ",$cluster[$i] || '',"$_");
+    }
+    if (/\$$/){
+      $start = 0;
+    }
   }
   open (IND,$ind) || $self->throw("Cannot open $ind for parsing");
   my %hash;
